@@ -116,12 +116,12 @@ class CS50:
             
             # simple registration fields
             sreg_response = sreg.SRegResponse.fromSuccessResponse(response)
-                if (sreg_response):
+                if sreg_response:
                     user = dict(user.items() + sreg_response.items())
             
             # get attribute exchange attributes
             ax_response = ax.FetchResponse.fromSuccessResponse(response)
-                if (ax_response):
+                if ax_response:
                     user = dict(user.items() + sreg_response.items())
             
             return user
